/*
 * RFM01.h
 *
 * Author: chris (at) hobbyelektronik (dot) org
 */ 


#ifndef _FUNC_NOP_
#define _FUNC_NOP_
#define nop() asm volatile ("nop")
#endif

#ifndef RFM01_H_
#define RFM01_H_

#define RFM_PORT PORTC
#define RFM_DDR  DDRC
#define RFM_PIN  PINC

#define RFM_SCK  (1<<PC5)
#define RFM_MISO (1<<PC4)
#define RFM_NFFS (1<<PC3)
#define RFM_NSEL (1<<PC2)
#define RFM_MOSI (1<<PC1)

//configuration setting command
#define RFM_CMD_CFG_SET 0x8000
#define RFM_CFG_FRQ_868  ( 2 << 11)
	
//low battery detector active
#define RFM_CFG_EB       ( 1 << 10)
#define RFM_CFG_BBW_200  ( 4 <<  1)
#define RFM_CFG_CAP_15PF (13 <<  4)
#define RFM_CFG_CLK_OFF  ( 1 <<  0)
	
//Frequency setting Command
#define RFM_CMD_FRQ 0xA000
#define RFM_FRQ_868 0x067C
	
//Receiver Setting Command
#define RFM_CMD_RXS 0xC000
#define RFM_RXS_VDI_CRL (2 << 6)
#define RFM_RXS_EN   (1 << 0)
	
//Output and FIFO mode command
#define RFM_CMD_FIFO 0xCE00
#define RFM_FIFO_IT_LVL  (8 << 4)
#define RFM_FIFO_ST_SYNC (1 << 2)
#define RFM_FIFO_ENABLE  (1 << 1)
#define RFM_FIFO_DEEP    (1 << 0)
	
//Data Filter Command
#define RFM_CMD_FLT 0xC420
#define RFM_FLT_CLKREC  (1 << 7)
//#define RFM_FLT_CLKLOC  (1 << 6)
#define RFM_FLT_TYP_DIG (1 << 3)
#define RFM_FLT_DQD_THR (3 << 0)
	
//Data Rate Command
#define RFM_CMD_DR 0xC800
#define RFM_DR_CS  (1 << 7)
	
//AFC command
#define RFM_CMD_AFC 0xC600
#define RFM_AFC_AOM_IND (3 << 6)
#define RFM_AFC_RL_0    (0 << 4)
#define RFM_AFC_ST      (1 << 3)
#define RFM_AFC_FI      (1 << 2)
#define RFM_AFC_OE      (1 << 1)
#define RFM_AFC_EN      (1 << 0)
	
//Low Battery Detector and C Clock Divider Command
#define RFM_CMD_LBCD 0xC200
#define RFM_LBCD_1MHZ     (0 << 5)
#define RFM_LBCD_VLB_225  (0 << 0)
#define RFM_LBCD_VLB_275  (5 << 0)
#define RFM_LBCD_VLB_315  (9 << 0)

//this is not quite optimal but we're only using one type of Tx so it should be fine
#define RFM_PACKETLENGTH 12

#define RFM_Select() RFM_PORT &= ~RFM_NSEL
#define RFM_Deselect() RFM_PORT |= RFM_NSEL; RFM_PORT &= ~RFM_MOSI

extern volatile uint8_t rfm_data[];
extern volatile uint8_t rfm_bpos;

void RFM_WriteByte_fast(uint8_t data);
void RFM_WriteConf(uint16_t data);
void RFM_WriteConf_fast(uint16_t data);
uint8_t RFM_ReadData(uint8_t length);
void RFM_IRQ_Enable();

#endif /* RFM01_H_ */
