#include <stdlib.h>
#include <avr/interrupt.h>
#include <avr/io.h>
#include "uart.h"

void uart_init(void) {
   #define BAUD 57600
   #include <util/setbaud.h>
   UBRRH = UBRRH_VALUE;
   UBRRL = UBRRL_VALUE;
   
   #if USE_2X
	UCSRA |= (1 << U2X);
   #else
	UCSRA &= ~(1 << U2X);
   #endif
   UCR =(1 << TXEN);
}

void uart_putc(char c) {
    while(!(USR & (1<<UDRE)));
    UDR = c;
}


void uart_puts(char *s) {
	while(*s) {
		uart_putc(*s++);
	}
}

void uart_puts_flash(const char *s) {
	char c = pgm_read_byte(s++);
	while(c != '\0') {
		uart_putc(c);
		c = pgm_read_byte(s++);
	}
}

void uart_putu(uint16_t i) {
	char buff[6];
	utoa(i, buff, 10);
	uart_puts(buff);
}

void uart_puthex(uint8_t i) {
	char c = i>>4;
	if(c >= 10) {
		c = c - 10 + 'A';
	} else {
		c = c + '0';
	}
	uart_putc(c);
	
	c = i & 0x0F;
	if(c >= 10) {
		c = c - 10 + 'A';
	} else {
		c = c + '0';
	}
	uart_putc(c);
	
}

void uart_puthhex(uint8_t i) {
	char c = i & 0x0F;
	if(c >= 10) {
		c = c - 10 + 'A';
	} else {
		c = c + '0';
	}
	uart_putc(c);
	
}